Module protocol

Module protocol 

Structs

Cell
A single executed cell: the script the model wrote and its output.
Notebook
Accumulated history of all cells executed in one RLM run.

Enums

StepResult
The result of executing one Rhai cell in the RLM loop.